# CDF FAQ

## What is Continuous Delivery (CD)?

CD is a software engineering approach in which teams produce software in short cycles, ensuring that the software can be reliably released at any time. The rise of microservices, cloud native architectures has caused a corollary rise in continuous delivery practices. This is related to CI/CD that includes Continuous Integration (CI) -- the practice of merging all developer working copies to a shared mainline several times a day.

## What is Continuous Delivery Foundation (CDF)?

The [Continuous Delivery Foundation (CDF](https://cd.foundation/) is a neutral organization, working on the growth and sustainability of an open continuous delivery ecosystem. It provides unified governance and vendor-neutral stewardship, as well as oversight of funding and operations.

The current projects under the CD Foundation are

* [CDEvents](https://cdevents.dev/)
* [Jenkins](https://www.jenkins.io/)
* [Jenkins X](https://jenkins-x.io/)
* [Ortelius](https://ortelius.io/)
* [Screwdriver](https://screwdriver.cd/)
* [Shipwright](https://shipwright.io/)
* [Spinnaker](https://spinnaker.io/)
* [Tekton](https://tekton.dev/)



The projects and their details are available on [the CD Foundation website](https://cd.foundation/projects/) and [the CD Foundation CD Landscape](https://landscape.cd.foundation/).

## Why did the CD community form the foundation? Why is it needed?

There is a strong need across the industry to collaborate on defining industry specifications around pipelines, workflows and other CI/CD areas, as well as provide foundational support for CI/CD tools. For example, the Jenkins community is seeking a "full service" foundation to host Jenkins (one of the most popular CI/CD projects) and build a platform for increased collaboration. There is also a desire for an industry-wide neutral DevOps/CD conference.

## Does this represent a shift in the cloud native ecosystem?

Yes, the market has shifted to containerized and cloud native technologies, so the ecosystem of CI/CD systems, DevOps and related tools has radically changed. The CNCF Cloud Native Interactive Landscape illustrates how diverse the [CI/CD space](https://landscape.cncf.io/category=continuous-integration-delivery&format=card-mode&grouping=category) is and the many projects and vendors active in the space.

By establishing a vendor-neutral CDF, the industry’s top developers, end users, and vendors can evangelize CI/CD as methodologies, define/document best practices, and create training materials to enable any software development team around the world to deliver code changes faster and more reliably, whether they are cloud native or not.

## Why should developers care?

The challenges CI/CD projects face today, including tool complexity and lack of industry standardization around pipelines and other CI/CD tools, are stifling growth and innovation. Lacking a neutral, legal entity and strong governance, projects struggle to attract valuable support from new developers and organizations. Project maintainers and developers spend a significant amount of time and money on workarounds in areas such as interoperability, security and oversight. This takes attention away from new development and innovation. A foundation with broad industry support will be able to more quickly define industry specs and create more opportunities for cross-project collaboration to improve tools for developers.

## Who uses CD?

CD is widely utilized across cloud computing, enterprise IT, and is rapidly expanding into other top industry verticals. In networking, for example, operators are working side by side with vendors to develop CI/CD tooling that enables developers to work directly with branches of upstream projects -- slashing the time to implement new features and address bugs from months to days. When working with cloud native technologies, like [Kubernetes](https://kubernetes.io/), setting up a CI/CD pipeline will speed up the release lifecycle. This enables the developer to release multiple times a day, keeping teams nimble enough to iterate quickly.

## How does CDF relate to progressive delivery?

Progressive delivery is a form of modern continuous delivery techniques such as canarying, feature flags, A/B testing, validated deploy groups and more. Progressive delivery techniques and technologies go hand and hand with continuous delivery. For more information on what progressive delivery is, read James Governor’s Redmonk blog on this topic: [https://redmonk.com/jgovernor/2018/08/06/towards-progressive-delivery/](https://redmonk.com/jgovernor/2018/08/06/towards-progressive-delivery/)

## How will this impact the development of open source software?

Continuous delivery improves velocity, productivity, and sustainability of software development teams. The CDF fosters collaboration between the industry’s top developers, end users and vendors to ensure that the CD approach to software engineering reaches its full potential to advance open source software development.

## Do I have to be a member to contribute to CDF projects?

Absolutely not, technical contributions to open source projects in the CDF or any Linux Foundation initiative do not require membership. Organizations join CDF as members because they want to take an active role in supporting the growth and evolution of continuous delivery models and best practices on top of sustaining the open source projects within the CDF. If you are interested in joining, please see [https://cd.foundation/members/join/](https://cd.foundation/members/join/).

## Do I have to pay to play or contribute to a CDF project?

As answered above, CDF is a "pay to sustain" organization and no technical contributions require membership.  The members of CDF have a voice in how the budget is spent to sustain the organization for the long term (think events, marketing, infrastructure, diversity scholarships and so on).

## How is the CNCF involved and why was a separate foundation necessary?

The first thing to note is that CD is applicable across the entire software industry and just not modern cloud native applications. [The Cloud Native Computing Foundation](http://cncf.io) (CNCF) is a sister foundation to the CDF with its [own governance structure and mission](https://github.com/cncf/foundation/blob/master/charter.md#1-mission-of-the-cloud-native-computing-foundation). Each foundation has a different mission as defined by their founding members and technical experts.  The CNCF believes most CD-related tooling is out of scope and broader than their focused cloud native [definition](https://github.com/cncf/toc/blob/master/DEFINITION.md), which is focused on containerization, microservices, service meshes, and orchestration. CDF goes beyond cloud and containers to include legacy infrastructure, mobile, IoT, bare metal and more. The CNCF and CDF are both under the larger Linux Foundation umbrella and plan to collaborate in many areas including co-locating conferences.

## How does the CDF support or work with other players in the DevOps space?

The CDF’s mission is to provide a neutral home for the developers, end users and vendors to collaborate on CI/CD methodologies. In this respect, CDF will support DevOps practitioners through the publication of best practices, training materials and industry guidelines focusing on portability, interoperability, and security.

Organizations interested in becoming members of the CDF and shaping its governance should visit the [CDF Join page](https://cd.foundation/members/join/). Developers can sign up to the [CDF Mailing List here](lists.cd.foundation/g/main). Any projects interested in joining the CDF, can contact the Technical Oversight Committee ("TOC") [https://github.com/cdfoundation/toc](https://github.com/cdfoundation/toc).

## Where can I learn more about CDF and stay up to date?

The CDF is always publishing content to support the projects of the CDF and the developers of those projects. We publish on topics of case studies, whitepapers, code releases, events, and much more. Get involved with the links below:

- [Newsletter](https://cd.foundation/stay-connected/)
- [Email Lists](https://lists.cd.foundation/g/main)
- [Blog](https://cd.foundation/blog/)
